#if !defined(__PARPRE_VECPIPE_PACKAGE)
#define __PARPRE_VECPIPE_PACKAGE

#include "parpre_pipeline.h"
#include "pc.h"

typedef struct _PCParallel_PipeInfo *PCParallel_PipeInfo;
typedef int (*PipelineFunction)(int,PetscObject);

struct _VecPipeline {
  PETSCHEADER(int)
  VecScatter scatter;
  PipelineType pipe_type; /* duplicated in the subdomain structure */
  VecScatter_MPI_General *upto,*upfrom,*dnto,*dnfrom;
  VecScatter_MPI_General *scatterto,*scatterfrom;
  PipelineFunction upfn,dnfn;
  int (*setup)(VecPipeline,PetscObject,PetscObject*);
  PetscObject aux_data;
  PetscObject custom_pipe_data;
  int setupcalled;
};

#endif
